pub struct TextArea<'a> {
pub buffer: &'a Buffer,
pub left: f32,
pub top: f32,
pub scale: f32,
pub bounds: TextBounds,
pub default_color: Color,
}Expand description
A text area containing text to be rendered along with its overflow behavior.
Fields
buffer: &'a BufferThe buffer containing the text to be rendered.
left: f32The left edge of the buffer.
top: f32The top edge of the buffer.
scale: f32The scaling to apply to the buffer.
bounds: TextBoundsThe visible bounds of the text area. This is used to clip the text and doesn’t have to
match the left and top values.
default_color: ColorTrait Implementations