TextBounds

Struct TextBounds 

pub struct TextBounds {
    pub left: i32,
    pub top: i32,
    pub right: i32,
    pub bottom: i32,
}
Controls the visible area of the text. Any text outside of the visible area will be clipped.

Fields

left: i32

The position of the left edge of the visible area.

top: i32

The position of the top edge of the visible area.

right: i32

The position of the right edge of the visible area.

bottom: i32

The position of the bottom edge of the visible area.