TextRenderer

Struct TextRenderer 

pub struct TextRenderer { /* private fields */ }
A text renderer that uses cached glyphs to render text into an existing render pass.

Implementations

Source

impl TextRenderer

pub fn new( atlas: &mut TextAtlas, device: &Device, multisample: MultisampleState, depth_stencil: Option<DepthStencilState>, ) -> Self

Creates a new TextRenderer.

pub fn prepare_with_depth<'a>( &mut self, device: &Device, queue: &Queue, encoder: &mut CommandEncoder, font_system: &mut FontSystem, atlas: &mut TextAtlas, viewport: &Viewport, text_areas: impl IntoIterator<Item = TextArea<'a>>, cache: &mut SwashCache, metadata_to_depth: impl FnMut(usize) -> f32, ) -> Result<(), PrepareError>

Prepares all of the provided text areas for rendering.

pub fn prepare<'a>( &mut self, device: &Device, queue: &Queue, encoder: &mut CommandEncoder, font_system: &mut FontSystem, atlas: &mut TextAtlas, viewport: &Viewport, text_areas: impl IntoIterator<Item = TextArea<'a>>, cache: &mut SwashCache, ) -> Result<(), PrepareError>

pub fn render( &self, atlas: &TextAtlas, viewport: &Viewport, pass: &mut RenderPass<'_>, ) -> Result<(), RenderError>

Renders all layouts that were previously provided to prepare.