pub struct TextBounds {
pub left: i32,
pub top: i32,
pub right: i32,
pub bottom: i32,
}Expand description
Controls the visible area of the text. Any text outside of the visible area will be clipped.
Fields
left: i32The position of the left edge of the visible area.
top: i32The position of the top edge of the visible area.
right: i32The position of the right edge of the visible area.
bottom: i32The position of the bottom edge of the visible area.